@@ -48,7 +48,7 @@ class _PKDEMainMixin(kdeui.KMainWindow, _PKDECommunicator):
     w = property(_get_w)
     
     def set_caption(self, caption):
-        self.setCaption(caption)
+        self.setPlainCaption(caption)
     
     def sizetoscreen(self, maximized):
         if maximized:
@@ -130,7 +130,6 @@ class PKDEApplication(kdecore.KApplication, app.PApplicationBase, _PKDECommunica
         kdecore.KApplication.__init__(self)
         app.PApplicationBase.__init__(self, arglist, cls)
         self.mainwin = self.createMainWidget()
-        # FIXME: something in here is resetting the caption? maybe the next line?
         self.setMainWidget(self.mainwin)
         
         # 'automagic' signal connection
