@@ -4,13 +4,17 @@ Module COMBO -- GUI Combo Box Widgets
 Sub-Package GUI.WIDGETS of Package PLIB -- Python GUI Framework
 Copyright (C) 2008 by Peter A. Donis
 
+Released under the GNU General Public License, Version 2
+See the LICENSE and README files for more information
+
 Defines the widget classes for combo box widgets.
 """
 
 from plib.stdlib import baselist, SortMixin
 from plib.gui.defs import *
+from plib.gui._widgets import _control
 
-class PComboBoxBase(SortMixin, baselist):
+class PComboBoxBase(_control._PDialogControl, SortMixin, baselist):
     """
     Combo box that looks like a list of strings.
     
@@ -19,14 +23,11 @@ class PComboBoxBase(SortMixin, baselist):
     control and add new items to the pick list.)
     """
     
-    def __init__(self, sequence=None, geometry=None):
-        baselist.__init__(self, sequence)
-        if geometry is not None:
-            self.set_geometry(*geometry)
+    signal = SIGNAL_SELECTED
     
-    def set_geometry(self, left, top, width, height):
-        """ Placeholder for derived classes to implement. """
-        raise NotImplementedError
+    def __init__(self, sequence=None, target=None, geometry=None):
+        _control._PDialogControl.__init__(self, target, geometry)
+        baselist.__init__(self, sequence)
     
     def current_text(self):
         return self[self.current_index()]
