@@ -4,6 +4,9 @@ Module MAIN -- Top-Level GUI Module
 Sub-Package GUI of Package PLIB -- Python GUI Framework
 Copyright (C) 2008 by Peter A. Donis
 
+Released under the GNU General Public License, Version 2
+See the LICENSE and README files for more information
+
 This is the main module for the GUI sub-package; its
 namespace contains all the GUI classes and constants
 and the runapp() function which should be the main function
@@ -74,6 +77,7 @@ def toolkit_helper(toolkit, modname, klassname):
     return f
 
 toolkit_list = [
+    ('label', ['TextLabel']),
     ('button', ['Button', 'CheckBox']),
     ('combo', ['ComboBox']),
     ('editctrl', ['EditBox', 'EditControl']),
@@ -81,6 +85,7 @@ toolkit_list = [
     ('listview', ['ListViewLabels', 'ListViewItem', 'ListView']),
     ('tabwidget', ['TabWidget']),
     ('panel', ['Panel']),
+    ('statusbar', ['StatusBar']),
     ('action', ['Menu', 'ToolBar', 'Action']),
     ('mainwin', ['MessageBox', 'FileDialog', 'MainWindow']) ]
 
@@ -100,13 +105,31 @@ widget_list = [
     ('PTableRow', 'table'),
     ('PListViewItemCols', 'listview') ]
 
-toolkit_dict.update((klassname, widget_helper(klassname, modname)) for klassname, modname in widget_list)
+toolkit_dict.update((klassname, widget_helper(klassname, modname))
+    for klassname, modname in widget_list)
+
+# Standalone class entries for namespace dictionary
+
+def class_helper(modname, klassname):
+    def f():
+        return getattr(getattr(getattr(
+            __import__('plib.gui.%s' % modname), 'gui'), modname), klassname)
+    f.__name__ = '%s_%s' % (modname.lstrip('_'), klassname)
+    return f
+
+class_list = [
+    ('_classes', ['PHeaderLabel']),
+    ('_edit', ['PEditor', 'PFileEditor']) ]
+
+toolkit_dict.update((klassname, class_helper(modname, klassname))
+    for modname, klassnames in class_list for klassname in klassnames)
 
 # 'Mixin' entries for namespace dictionary
 
 def mixin_helper(klassname, bases):
     def f():
-        baselist = [ getattr(getattr(getattr(__import__('plib.gui.%s' % modname), 'gui'), modname), basename)
+        baselist = [ getattr(getattr(getattr(
+            __import__('plib.gui.%s' % modname), 'gui'), modname), basename)
             for modname, basename in bases ]
         result = type(klassname, tuple(baselist), {})
         
@@ -119,10 +142,12 @@ def mixin_helper(klassname, bases):
     return f
 
 mixin_list = [
-    ('PTableEditor', [('_mixins', 'PTableMixin'), ('edit', 'PEditor')]),
-    ('PAutoPanel', [('_mixins', 'PPanelMixin'), ('main', 'PPanel')]) ]
+    ('PTableEditor', [('_mixins', 'PTableMixin'), ('main', 'PEditor')]),
+    ('PAutoPanel', [('_mixins', 'PPanelMixin'), ('main', 'PPanel')]),
+    ('PAutoStatusBar', [('_mixins', 'PStatusMixin'), ('main', 'PStatusBar')]) ]
 
-toolkit_dict.update((klassname, mixin_helper(klassname, bases)) for klassname, bases in mixin_list)
+toolkit_dict.update((klassname, mixin_helper(klassname, bases))
+    for klassname, bases in mixin_list)
 
 # Now set up module proxy to 'lazy import' toolkit items as needed; note that
 # we don't need to bind it to a variable in this module because it installs
@@ -132,8 +157,8 @@ ModuleProxy(__name__, toolkit_dict)
 
 # Clean up namespace (and allow memory for helper items to be released,
 # since they've done their job and we don't need them any more)
-del ModuleProxy, toolkit_helper, widget_helper, mixin_helper, \
-    widget_list, mixin_list, toolkit_list, toolkit_dict, \
+del ModuleProxy, toolkit_helper, widget_helper, class_helper, mixin_helper, \
+    toolkit_dict, toolkit_list, widget_list, class_list, mixin_list, \
     GUI_KDE, GUI_QT, GUI_GTK, GUI_WX
 
 # Utility function for running application
